@@ -70,6 +70,8 @@ DRIVERS = {
         ('libcloud.compute.drivers.rackspace', 'RackspaceNodeDriver'),
     Provider.RACKSPACE_UK:
         ('libcloud.compute.drivers.rackspace', 'RackspaceUKNodeDriver'),
+    Provider.RACKSPACE_AU:
+        ('libcloud.compute.drivers.rackspace', 'RackspaceAUNodeDriver'),
     Provider.SLICEHOST:
         ('libcloud.compute.drivers.slicehost', 'SlicehostNodeDriver'),
     Provider.VPSNET:
@@ -129,7 +131,9 @@ DRIVERS = {
     Provider.HOSTVIRTUAL:
         ('libcloud.compute.drivers.hostvirtual', 'HostVirtualNodeDriver'),
     Provider.ABIQUO:
-        ('libcloud.compute.drivers.abiquo', 'AbiquoNodeDriver')
+        ('libcloud.compute.drivers.abiquo', 'AbiquoNodeDriver'),
+    Provider.DIGITAL_OCEAN:
+        ('libcloud.compute.drivers.digitalocean', 'DigitalOceanNodeDriver')
 }
 
 
